@@ -28,7 +28,6 @@ from __future__ import annotations
 
 import logging
 import os
-from functools import cached_property
 from typing import TYPE_CHECKING, Any, cast
 
 from asgiref.sync import sync_to_async
@@ -46,13 +45,13 @@ from azure.storage.blob.aio import (
 )
 
 from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import BaseHook
 from airflow.providers.microsoft.azure.utils import (
     add_managed_identity_connection_widgets,
     get_async_default_azure_credential,
     get_sync_default_azure_credential,
     parse_blob_account_url,
 )
-from airflow.providers.microsoft.azure.version_compat import BaseHook
 
 if TYPE_CHECKING:
     from azure.core.credentials import TokenCredential
@@ -137,6 +136,7 @@ class WasbHook(BaseHook):
         super().__init__()
         self.conn_id = wasb_conn_id
         self.public_read = public_read
+        self._blob_service_client: AsyncBlobServiceClient | BlobServiceClient | None = None
 
         logger = logging.getLogger("azure.core.pipeline.policies.http_logging_policy")
         try:
@@ -154,10 +154,17 @@ class WasbHook(BaseHook):
             return extra_dict[field_name] or None
         return extra_dict.get(f"{prefix}{field_name}") or None
 
-    @cached_property
-    def blob_service_client(self) -> BlobServiceClient:
+    @property
+    def blob_service_client(self) -> AsyncBlobServiceClient | BlobServiceClient:
         """Return the BlobServiceClient object (cached)."""
-        return self.get_conn()
+        if self._blob_service_client is None:
+            self._blob_service_client = self.get_conn()
+        return self._blob_service_client
+
+    @blob_service_client.setter
+    def blob_service_client(self, client: AsyncBlobServiceClient) -> None:
+        """Set the cached BlobServiceClient object."""
+        self._blob_service_client = client
 
     def get_conn(self) -> BlobServiceClient:
         """Return the BlobServiceClient object."""
@@ -220,13 +227,12 @@ class WasbHook(BaseHook):
             **extra,
         )
 
-    # TODO: rework the interface as it might also return AsyncContainerClient
-    def _get_container_client(self, container_name: str) -> ContainerClient:
+    def _get_container_client(self, container_name: str) -> AsyncContainerClient | ContainerClient:
         """
         Instantiate a container client.
 
         :param container_name: The name of the container
-        :return: ContainerClient
+        :return: AsyncContainerClient | ContainerClient
         """
         return self.blob_service_client.get_container_client(container_name)
 
@@ -266,6 +272,12 @@ class WasbHook(BaseHook):
         blobs = self.get_blobs_list(container_name=container_name, prefix=prefix, **kwargs)
         return bool(blobs)
 
+    def check_for_variable_type(self, variable_name: str, container: Any, expected_type: type[Any]) -> None:
+        if not isinstance(container, expected_type):
+            raise TypeError(
+                f"{variable_name} for {self.__class__.__name__} must be {expected_type.__name__}, got {type(container).__name__}"
+            )
+
     def get_blobs_list(
         self,
         container_name: str,
@@ -286,6 +298,9 @@ class WasbHook(BaseHook):
         :param delimiter: filters objects based on the delimiter (for e.g '.csv')
         """
         container = self._get_container_client(container_name)
+        self.check_for_variable_type("container", container, ContainerClient)
+        container = cast("ContainerClient", container)
+
         blob_list = []
         blobs = container.walk_blobs(name_starts_with=prefix, include=include, delimiter=delimiter, **kwargs)
         for blob in blobs:
@@ -312,8 +327,12 @@ class WasbHook(BaseHook):
         :param delimiter: filters objects based on the delimiter (for e.g '.csv')
         """
         container = self._get_container_client(container_name)
+        self.check_for_variable_type("container", container, ContainerClient)
+        container = cast("ContainerClient", container)
+
         blob_list = []
         blobs = container.list_blobs(name_starts_with=prefix, include=include, **kwargs)
+
         for blob in blobs:
             if blob.name.endswith(endswith):
                 blob_list.append(blob.name)
@@ -591,12 +610,16 @@ class WasbAsyncHook(WasbHook):
         """Initialize the hook instance."""
         self.conn_id = wasb_conn_id
         self.public_read = public_read
-        self.blob_service_client: AsyncBlobServiceClient = None  # type: ignore
+        self._blob_service_client: AsyncBlobServiceClient | BlobServiceClient | None = None
 
     async def get_async_conn(self) -> AsyncBlobServiceClient:
         """Return the Async BlobServiceClient object."""
-        if self.blob_service_client is not None:
-            return self.blob_service_client
+        if self._blob_service_client is not None:
+            self.check_for_variable_type(
+                "self._blob_service_client", self._blob_service_client, AsyncBlobServiceClient
+            )
+            self._blob_service_client = cast("AsyncBlobServiceClient", self._blob_service_client)
+            return self._blob_service_client
 
         conn = await sync_to_async(self.get_connection)(self.conn_id)
         extra = conn.extra_dejson or {}
@@ -605,7 +628,7 @@ class WasbAsyncHook(WasbHook):
         connection_string = self._get_field(extra, "connection_string")
         if connection_string:
             # connection_string auth takes priority
-            self.blob_service_client = AsyncBlobServiceClient.from_connection_string(
+            self.blob_service_client: AsyncBlobServiceClient = AsyncBlobServiceClient.from_connection_string(
                 connection_string, **extra
             )
             return self.blob_service_client
@@ -703,18 +726,6 @@ class WasbAsyncHook(WasbHook):
             return False
         return True
 
-    # TODO: rework the interface as in parent Hook it returns ContainerClient
-    def _get_container_client(self, container_name: str) -> AsyncContainerClient:  # type: ignore[override]
-        """
-        Instantiate a container client.
-
-        :param container_name: the name of the container
-        """
-        if self.blob_service_client is None:
-            raise AirflowException("BlobServiceClient is not initialized")
-
-        return self.blob_service_client.get_container_client(container_name)
-
     async def get_blobs_list_async(
         self,
         container_name: str,
@@ -735,6 +746,9 @@ class WasbAsyncHook(WasbHook):
         :param delimiter: filters objects based on the delimiter (for e.g '.csv')
         """
         container = self._get_container_client(container_name)
+        container = cast("AsyncContainerClient", container)
+        self.check_for_variable_type("container", container, AsyncContainerClient)
+
         blob_list: list[BlobProperties | BlobPrefix] = []
         blobs = container.walk_blobs(name_starts_with=prefix, include=include, delimiter=delimiter, **kwargs)
         async for blob in blobs:
